# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPortIdsResult',
    'AwaitableGetPortIdsResult',
    'get_port_ids',
    'get_port_ids_output',
]

@pulumi.output_type
class GetPortIdsResult:
    """
    A collection of values returned by getPortIds.
    """
    def __init__(__self__, admin_state_up=None, description=None, device_id=None, device_owner=None, dns_name=None, fixed_ip=None, id=None, ids=None, mac_address=None, name=None, network_id=None, project_id=None, region=None, security_group_ids=None, sort_direction=None, sort_key=None, status=None, tags=None, tenant_id=None):
        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError("Expected argument 'admin_state_up' to be a bool")
        pulumi.set(__self__, "admin_state_up", admin_state_up)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if device_id and not isinstance(device_id, str):
            raise TypeError("Expected argument 'device_id' to be a str")
        pulumi.set(__self__, "device_id", device_id)
        if device_owner and not isinstance(device_owner, str):
            raise TypeError("Expected argument 'device_owner' to be a str")
        pulumi.set(__self__, "device_owner", device_owner)
        if dns_name and not isinstance(dns_name, str):
            raise TypeError("Expected argument 'dns_name' to be a str")
        pulumi.set(__self__, "dns_name", dns_name)
        if fixed_ip and not isinstance(fixed_ip, str):
            raise TypeError("Expected argument 'fixed_ip' to be a str")
        pulumi.set(__self__, "fixed_ip", fixed_ip)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if mac_address and not isinstance(mac_address, str):
            raise TypeError("Expected argument 'mac_address' to be a str")
        pulumi.set(__self__, "mac_address", mac_address)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_id and not isinstance(network_id, str):
            raise TypeError("Expected argument 'network_id' to be a str")
        pulumi.set(__self__, "network_id", network_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if security_group_ids and not isinstance(security_group_ids, list):
            raise TypeError("Expected argument 'security_group_ids' to be a list")
        pulumi.set(__self__, "security_group_ids", security_group_ids)
        if sort_direction and not isinstance(sort_direction, str):
            raise TypeError("Expected argument 'sort_direction' to be a str")
        pulumi.set(__self__, "sort_direction", sort_direction)
        if sort_key and not isinstance(sort_key, str):
            raise TypeError("Expected argument 'sort_key' to be a str")
        pulumi.set(__self__, "sort_key", sort_key)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "admin_state_up")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="deviceId")
    def device_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "device_id")

    @_builtins.property
    @pulumi.getter(name="deviceOwner")
    def device_owner(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "device_owner")

    @_builtins.property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "dns_name")

    @_builtins.property
    @pulumi.getter(name="fixedIp")
    def fixed_ip(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "fixed_ip")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ids(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "ids")

    @_builtins.property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "mac_address")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "security_group_ids")

    @_builtins.property
    @pulumi.getter(name="sortDirection")
    def sort_direction(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "sort_direction")

    @_builtins.property
    @pulumi.getter(name="sortKey")
    def sort_key(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "sort_key")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "tenant_id")


class AwaitableGetPortIdsResult(GetPortIdsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPortIdsResult(
            admin_state_up=self.admin_state_up,
            description=self.description,
            device_id=self.device_id,
            device_owner=self.device_owner,
            dns_name=self.dns_name,
            fixed_ip=self.fixed_ip,
            id=self.id,
            ids=self.ids,
            mac_address=self.mac_address,
            name=self.name,
            network_id=self.network_id,
            project_id=self.project_id,
            region=self.region,
            security_group_ids=self.security_group_ids,
            sort_direction=self.sort_direction,
            sort_key=self.sort_key,
            status=self.status,
            tags=self.tags,
            tenant_id=self.tenant_id)


def get_port_ids(admin_state_up: Optional[_builtins.bool] = None,
                 description: Optional[_builtins.str] = None,
                 device_id: Optional[_builtins.str] = None,
                 device_owner: Optional[_builtins.str] = None,
                 dns_name: Optional[_builtins.str] = None,
                 fixed_ip: Optional[_builtins.str] = None,
                 mac_address: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None,
                 network_id: Optional[_builtins.str] = None,
                 project_id: Optional[_builtins.str] = None,
                 region: Optional[_builtins.str] = None,
                 security_group_ids: Optional[Sequence[_builtins.str]] = None,
                 sort_direction: Optional[_builtins.str] = None,
                 sort_key: Optional[_builtins.str] = None,
                 status: Optional[_builtins.str] = None,
                 tags: Optional[Sequence[_builtins.str]] = None,
                 tenant_id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPortIdsResult:
    """
    Use this data source to get a list of Openstack Port IDs matching the
    specified criteria.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    ports = openstack.networking.get_port_ids(name="port")
    ```


    :param _builtins.bool admin_state_up: The administrative state of the port.
    :param _builtins.str description: Human-readable description of the port.
    :param _builtins.str device_id: The ID of the device the port belongs to.
    :param _builtins.str device_owner: The device owner of the port.
    :param _builtins.str fixed_ip: The port IP address filter.
    :param _builtins.str mac_address: The MAC address of the port.
    :param _builtins.str name: The name of the port.
    :param _builtins.str network_id: The ID of the network the port belongs to.
    :param _builtins.str project_id: The owner of the port.
    :param _builtins.str region: The region in which to obtain the V2 Neutron client.
           A Neutron client is needed to retrieve port ids. If omitted, the
           `region` argument of the provider is used.
    :param Sequence[_builtins.str] security_group_ids: The list of port security group IDs to filter.
    :param _builtins.str sort_direction: Order the results in either `asc` or `desc`.
           Defaults to none.
    :param _builtins.str sort_key: Sort ports based on a certain key. Defaults to none.
    :param _builtins.str status: The status of the port.
    :param Sequence[_builtins.str] tags: The list of port tags to filter.
    """
    __args__ = dict()
    __args__['adminStateUp'] = admin_state_up
    __args__['description'] = description
    __args__['deviceId'] = device_id
    __args__['deviceOwner'] = device_owner
    __args__['dnsName'] = dns_name
    __args__['fixedIp'] = fixed_ip
    __args__['macAddress'] = mac_address
    __args__['name'] = name
    __args__['networkId'] = network_id
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['securityGroupIds'] = security_group_ids
    __args__['sortDirection'] = sort_direction
    __args__['sortKey'] = sort_key
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['tenantId'] = tenant_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('openstack:networking/getPortIds:getPortIds', __args__, opts=opts, typ=GetPortIdsResult).value

    return AwaitableGetPortIdsResult(
        admin_state_up=pulumi.get(__ret__, 'admin_state_up'),
        description=pulumi.get(__ret__, 'description'),
        device_id=pulumi.get(__ret__, 'device_id'),
        device_owner=pulumi.get(__ret__, 'device_owner'),
        dns_name=pulumi.get(__ret__, 'dns_name'),
        fixed_ip=pulumi.get(__ret__, 'fixed_ip'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        mac_address=pulumi.get(__ret__, 'mac_address'),
        name=pulumi.get(__ret__, 'name'),
        network_id=pulumi.get(__ret__, 'network_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        security_group_ids=pulumi.get(__ret__, 'security_group_ids'),
        sort_direction=pulumi.get(__ret__, 'sort_direction'),
        sort_key=pulumi.get(__ret__, 'sort_key'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        tenant_id=pulumi.get(__ret__, 'tenant_id'))
def get_port_ids_output(admin_state_up: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                        description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        device_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        device_owner: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        dns_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        fixed_ip: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        mac_address: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        network_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        security_group_ids: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                        sort_direction: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        sort_key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        status: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                        tenant_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPortIdsResult]:
    """
    Use this data source to get a list of Openstack Port IDs matching the
    specified criteria.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    ports = openstack.networking.get_port_ids(name="port")
    ```


    :param _builtins.bool admin_state_up: The administrative state of the port.
    :param _builtins.str description: Human-readable description of the port.
    :param _builtins.str device_id: The ID of the device the port belongs to.
    :param _builtins.str device_owner: The device owner of the port.
    :param _builtins.str fixed_ip: The port IP address filter.
    :param _builtins.str mac_address: The MAC address of the port.
    :param _builtins.str name: The name of the port.
    :param _builtins.str network_id: The ID of the network the port belongs to.
    :param _builtins.str project_id: The owner of the port.
    :param _builtins.str region: The region in which to obtain the V2 Neutron client.
           A Neutron client is needed to retrieve port ids. If omitted, the
           `region` argument of the provider is used.
    :param Sequence[_builtins.str] security_group_ids: The list of port security group IDs to filter.
    :param _builtins.str sort_direction: Order the results in either `asc` or `desc`.
           Defaults to none.
    :param _builtins.str sort_key: Sort ports based on a certain key. Defaults to none.
    :param _builtins.str status: The status of the port.
    :param Sequence[_builtins.str] tags: The list of port tags to filter.
    """
    __args__ = dict()
    __args__['adminStateUp'] = admin_state_up
    __args__['description'] = description
    __args__['deviceId'] = device_id
    __args__['deviceOwner'] = device_owner
    __args__['dnsName'] = dns_name
    __args__['fixedIp'] = fixed_ip
    __args__['macAddress'] = mac_address
    __args__['name'] = name
    __args__['networkId'] = network_id
    __args__['projectId'] = project_id
    __args__['region'] = region
    __args__['securityGroupIds'] = security_group_ids
    __args__['sortDirection'] = sort_direction
    __args__['sortKey'] = sort_key
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['tenantId'] = tenant_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('openstack:networking/getPortIds:getPortIds', __args__, opts=opts, typ=GetPortIdsResult)
    return __ret__.apply(lambda __response__: GetPortIdsResult(
        admin_state_up=pulumi.get(__response__, 'admin_state_up'),
        description=pulumi.get(__response__, 'description'),
        device_id=pulumi.get(__response__, 'device_id'),
        device_owner=pulumi.get(__response__, 'device_owner'),
        dns_name=pulumi.get(__response__, 'dns_name'),
        fixed_ip=pulumi.get(__response__, 'fixed_ip'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        mac_address=pulumi.get(__response__, 'mac_address'),
        name=pulumi.get(__response__, 'name'),
        network_id=pulumi.get(__response__, 'network_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        security_group_ids=pulumi.get(__response__, 'security_group_ids'),
        sort_direction=pulumi.get(__response__, 'sort_direction'),
        sort_key=pulumi.get(__response__, 'sort_key'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        tenant_id=pulumi.get(__response__, 'tenant_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointGroupArgs', 'EndpointGroup']

@pulumi.input_type
class EndpointGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a EndpointGroup resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the group.
               Changing this updates the description of the existing group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] endpoints: List of endpoints of the same type, for the endpoint group. The values will depend on the type.
               Changing this creates a new group.
        :param pulumi.Input[_builtins.str] name: The name of the group. Changing this updates the name of
               the existing group.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the group. Required if admin wants to
               create an endpoint group for another project. Changing this creates a new group.
        :param pulumi.Input[_builtins.str] type: The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
               Changing this creates a new group.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the group.
        Changing this updates the description of the existing group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of endpoints of the same type, for the endpoint group. The values will depend on the type.
        Changing this creates a new group.
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "endpoints", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the group. Changing this updates the name of
        the existing group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the group. Required if admin wants to
        create an endpoint group for another project. Changing this creates a new group.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
        Changing this creates a new group.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "value_specs", value)


@pulumi.input_type
class _EndpointGroupState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering EndpointGroup resources.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the group.
               Changing this updates the description of the existing group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] endpoints: List of endpoints of the same type, for the endpoint group. The values will depend on the type.
               Changing this creates a new group.
        :param pulumi.Input[_builtins.str] name: The name of the group. Changing this updates the name of
               the existing group.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the group. Required if admin wants to
               create an endpoint group for another project. Changing this creates a new group.
        :param pulumi.Input[_builtins.str] type: The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
               Changing this creates a new group.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The human-readable description for the group.
        Changing this updates the description of the existing group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of endpoints of the same type, for the endpoint group. The values will depend on the type.
        Changing this creates a new group.
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "endpoints", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the group. Changing this updates the name of
        the existing group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The owner of the group. Required if admin wants to
        create an endpoint group for another project. Changing this creates a new group.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
        Changing this creates a new group.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "value_specs", value)


@pulumi.type_token("openstack:vpnaas/endpointGroup:EndpointGroup")
class EndpointGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a V2 Neutron Endpoint Group resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        group1 = openstack.vpnaas.EndpointGroup("group_1",
            name="Group 1",
            type="cidr",
            endpoints=[
                "10.2.0.0/24",
                "10.3.0.0/24",
            ])
        ```

        ## Import

        Groups can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:vpnaas/endpointGroup:EndpointGroup group_1 832cb7f3-59fe-40cf-8f64-8350ffc03272
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the group.
               Changing this updates the description of the existing group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] endpoints: List of endpoints of the same type, for the endpoint group. The values will depend on the type.
               Changing this creates a new group.
        :param pulumi.Input[_builtins.str] name: The name of the group. Changing this updates the name of
               the existing group.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the group. Required if admin wants to
               create an endpoint group for another project. Changing this creates a new group.
        :param pulumi.Input[_builtins.str] type: The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
               Changing this creates a new group.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EndpointGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 Neutron Endpoint Group resource within OpenStack.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_openstack as openstack

        group1 = openstack.vpnaas.EndpointGroup("group_1",
            name="Group 1",
            type="cidr",
            endpoints=[
                "10.2.0.0/24",
                "10.3.0.0/24",
            ])
        ```

        ## Import

        Groups can be imported using the `id`, e.g.

        ```sh
        $ pulumi import openstack:vpnaas/endpointGroup:EndpointGroup group_1 832cb7f3-59fe-40cf-8f64-8350ffc03272
        ```

        :param str resource_name: The name of the resource.
        :param EndpointGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointGroupArgs.__new__(EndpointGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["endpoints"] = endpoints
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            __props__.__dict__["tenant_id"] = tenant_id
            __props__.__dict__["type"] = type
            __props__.__dict__["value_specs"] = value_specs
        super(EndpointGroup, __self__).__init__(
            'openstack:vpnaas/endpointGroup:EndpointGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            endpoints: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'EndpointGroup':
        """
        Get an existing EndpointGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The human-readable description for the group.
               Changing this updates the description of the existing group.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] endpoints: List of endpoints of the same type, for the endpoint group. The values will depend on the type.
               Changing this creates a new group.
        :param pulumi.Input[_builtins.str] name: The name of the group. Changing this updates the name of
               the existing group.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 Networking client.
               A Networking client is needed to create an endpoint group. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               group.
        :param pulumi.Input[_builtins.str] tenant_id: The owner of the group. Required if admin wants to
               create an endpoint group for another project. Changing this creates a new group.
        :param pulumi.Input[_builtins.str] type: The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
               Changing this creates a new group.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointGroupState.__new__(_EndpointGroupState)

        __props__.__dict__["description"] = description
        __props__.__dict__["endpoints"] = endpoints
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["type"] = type
        __props__.__dict__["value_specs"] = value_specs
        return EndpointGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The human-readable description for the group.
        Changing this updates the description of the existing group.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of endpoints of the same type, for the endpoint group. The values will depend on the type.
        Changing this creates a new group.
        """
        return pulumi.get(self, "endpoints")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the group. Changing this updates the name of
        the existing group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 Networking client.
        A Networking client is needed to create an endpoint group. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        group.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The owner of the group. Required if admin wants to
        create an endpoint group for another project. Changing this creates a new group.
        """
        return pulumi.get(self, "tenant_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the endpoints in the group. A valid value is subnet, cidr, network, router, or vlan.
        Changing this creates a new group.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Map of additional options.
        """
        return pulumi.get(self, "value_specs")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPoolV2Result',
    'AwaitableGetPoolV2Result',
    'get_pool_v2',
    'get_pool_v2_output',
]

@pulumi.output_type
class GetPoolV2Result:
    """
    A collection of values returned by getPoolV2.
    """
    def __init__(__self__, admin_state_up=None, alpn_protocols=None, ca_tls_container_ref=None, crl_container_ref=None, description=None, healthmonitor_id=None, id=None, lb_method=None, listeners=None, loadbalancer_id=None, loadbalancers=None, members=None, name=None, operating_status=None, pool_id=None, project_id=None, protocol=None, provisioning_status=None, region=None, session_persistences=None, tags=None, tls_ciphers=None, tls_container_ref=None, tls_enabled=None, tls_versions=None):
        if admin_state_up and not isinstance(admin_state_up, bool):
            raise TypeError("Expected argument 'admin_state_up' to be a bool")
        pulumi.set(__self__, "admin_state_up", admin_state_up)
        if alpn_protocols and not isinstance(alpn_protocols, list):
            raise TypeError("Expected argument 'alpn_protocols' to be a list")
        pulumi.set(__self__, "alpn_protocols", alpn_protocols)
        if ca_tls_container_ref and not isinstance(ca_tls_container_ref, str):
            raise TypeError("Expected argument 'ca_tls_container_ref' to be a str")
        pulumi.set(__self__, "ca_tls_container_ref", ca_tls_container_ref)
        if crl_container_ref and not isinstance(crl_container_ref, str):
            raise TypeError("Expected argument 'crl_container_ref' to be a str")
        pulumi.set(__self__, "crl_container_ref", crl_container_ref)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if healthmonitor_id and not isinstance(healthmonitor_id, str):
            raise TypeError("Expected argument 'healthmonitor_id' to be a str")
        pulumi.set(__self__, "healthmonitor_id", healthmonitor_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lb_method and not isinstance(lb_method, str):
            raise TypeError("Expected argument 'lb_method' to be a str")
        pulumi.set(__self__, "lb_method", lb_method)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if loadbalancer_id and not isinstance(loadbalancer_id, str):
            raise TypeError("Expected argument 'loadbalancer_id' to be a str")
        pulumi.set(__self__, "loadbalancer_id", loadbalancer_id)
        if loadbalancers and not isinstance(loadbalancers, list):
            raise TypeError("Expected argument 'loadbalancers' to be a list")
        pulumi.set(__self__, "loadbalancers", loadbalancers)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if operating_status and not isinstance(operating_status, str):
            raise TypeError("Expected argument 'operating_status' to be a str")
        pulumi.set(__self__, "operating_status", operating_status)
        if pool_id and not isinstance(pool_id, str):
            raise TypeError("Expected argument 'pool_id' to be a str")
        pulumi.set(__self__, "pool_id", pool_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if provisioning_status and not isinstance(provisioning_status, str):
            raise TypeError("Expected argument 'provisioning_status' to be a str")
        pulumi.set(__self__, "provisioning_status", provisioning_status)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if session_persistences and not isinstance(session_persistences, list):
            raise TypeError("Expected argument 'session_persistences' to be a list")
        pulumi.set(__self__, "session_persistences", session_persistences)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if tls_ciphers and not isinstance(tls_ciphers, str):
            raise TypeError("Expected argument 'tls_ciphers' to be a str")
        pulumi.set(__self__, "tls_ciphers", tls_ciphers)
        if tls_container_ref and not isinstance(tls_container_ref, str):
            raise TypeError("Expected argument 'tls_container_ref' to be a str")
        pulumi.set(__self__, "tls_container_ref", tls_container_ref)
        if tls_enabled and not isinstance(tls_enabled, bool):
            raise TypeError("Expected argument 'tls_enabled' to be a bool")
        pulumi.set(__self__, "tls_enabled", tls_enabled)
        if tls_versions and not isinstance(tls_versions, list):
            raise TypeError("Expected argument 'tls_versions' to be a list")
        pulumi.set(__self__, "tls_versions", tls_versions)

    @_builtins.property
    @pulumi.getter(name="adminStateUp")
    def admin_state_up(self) -> _builtins.bool:
        """
        The administrative state of the Pool, which is up (true)
        or down (false).
        """
        return pulumi.get(self, "admin_state_up")

    @_builtins.property
    @pulumi.getter(name="alpnProtocols")
    def alpn_protocols(self) -> Sequence[_builtins.str]:
        """
        A list of ALPN protocols.
        """
        return pulumi.get(self, "alpn_protocols")

    @_builtins.property
    @pulumi.getter(name="caTlsContainerRef")
    def ca_tls_container_ref(self) -> _builtins.str:
        """
        The reference of the key manager service secret
        containing a PEM format CA certificate bundle for tls_enabled pools.
        """
        return pulumi.get(self, "ca_tls_container_ref")

    @_builtins.property
    @pulumi.getter(name="crlContainerRef")
    def crl_container_ref(self) -> _builtins.str:
        """
        The reference of the key manager service secret
        containing a PEM format CA revocation list file for tls_enabled pools.
        """
        return pulumi.get(self, "crl_container_ref")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the pool.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="healthmonitorId")
    def healthmonitor_id(self) -> _builtins.str:
        """
        The ID of associated health monitor.
        """
        return pulumi.get(self, "healthmonitor_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lbMethod")
    def lb_method(self) -> _builtins.str:
        """
        The load-balancer algorithm, which is round-robin,
        least-connections, and so on.
        """
        return pulumi.get(self, "lb_method")

    @_builtins.property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetPoolV2ListenerResult']:
        """
        A list of listeners objects IDs.
        """
        return pulumi.get(self, "listeners")

    @_builtins.property
    @pulumi.getter(name="loadbalancerId")
    def loadbalancer_id(self) -> _builtins.str:
        return pulumi.get(self, "loadbalancer_id")

    @_builtins.property
    @pulumi.getter
    def loadbalancers(self) -> Sequence['outputs.GetPoolV2LoadbalancerResult']:
        """
        A list of load balancer objects IDs.
        """
        return pulumi.get(self, "loadbalancers")

    @_builtins.property
    @pulumi.getter
    def members(self) -> Sequence['outputs.GetPoolV2MemberResult']:
        """
        A list of member objects IDs.
        """
        return pulumi.get(self, "members")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the pool.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="operatingStatus")
    def operating_status(self) -> _builtins.str:
        """
        The operating status of the pool.
        """
        return pulumi.get(self, "operating_status")

    @_builtins.property
    @pulumi.getter(name="poolId")
    def pool_id(self) -> _builtins.str:
        return pulumi.get(self, "pool_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The owner (project/tenant) ID of the pool.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> _builtins.str:
        """
        The protocol to loadbalance.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="provisioningStatus")
    def provisioning_status(self) -> _builtins.str:
        """
        The provisioning status of the pool.
        """
        return pulumi.get(self, "provisioning_status")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="sessionPersistences")
    def session_persistences(self) -> Sequence['outputs.GetPoolV2SessionPersistenceResult']:
        """
        Indicates whether connections in the same session
        will be processed by the same Pool member or not.
        """
        return pulumi.get(self, "session_persistences")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags is a list of resource tags.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="tlsCiphers")
    def tls_ciphers(self) -> _builtins.str:
        """
        List of ciphers in OpenSSL format (colon-separated).
        """
        return pulumi.get(self, "tls_ciphers")

    @_builtins.property
    @pulumi.getter(name="tlsContainerRef")
    def tls_container_ref(self) -> _builtins.str:
        """
        The reference to the key manager service secret
        containing a PKCS12 format certificate/key bundle for tls_enabled pools for
        TLS client authentication to the member servers.
        """
        return pulumi.get(self, "tls_container_ref")

    @_builtins.property
    @pulumi.getter(name="tlsEnabled")
    def tls_enabled(self) -> _builtins.bool:
        """
        When true connections to backend member servers will use
        TLS encryption.
        """
        return pulumi.get(self, "tls_enabled")

    @_builtins.property
    @pulumi.getter(name="tlsVersions")
    def tls_versions(self) -> Sequence[_builtins.str]:
        """
        A list of TLS protocol versions.
        """
        return pulumi.get(self, "tls_versions")


class AwaitableGetPoolV2Result(GetPoolV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPoolV2Result(
            admin_state_up=self.admin_state_up,
            alpn_protocols=self.alpn_protocols,
            ca_tls_container_ref=self.ca_tls_container_ref,
            crl_container_ref=self.crl_container_ref,
            description=self.description,
            healthmonitor_id=self.healthmonitor_id,
            id=self.id,
            lb_method=self.lb_method,
            listeners=self.listeners,
            loadbalancer_id=self.loadbalancer_id,
            loadbalancers=self.loadbalancers,
            members=self.members,
            name=self.name,
            operating_status=self.operating_status,
            pool_id=self.pool_id,
            project_id=self.project_id,
            protocol=self.protocol,
            provisioning_status=self.provisioning_status,
            region=self.region,
            session_persistences=self.session_persistences,
            tags=self.tags,
            tls_ciphers=self.tls_ciphers,
            tls_container_ref=self.tls_container_ref,
            tls_enabled=self.tls_enabled,
            tls_versions=self.tls_versions)


def get_pool_v2(lb_method: Optional[_builtins.str] = None,
                loadbalancer_id: Optional[_builtins.str] = None,
                name: Optional[_builtins.str] = None,
                pool_id: Optional[_builtins.str] = None,
                protocol: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                tags: Optional[Sequence[_builtins.str]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPoolV2Result:
    """
    Use this data source to get the ID of an OpenStack Load Balancer pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    pool1 = openstack.loadbalancer.get_pool_v2(name="pool_1")
    ```


    :param _builtins.str lb_method: The load balancing algorithm to distribute traffic to the
           pool's members.
    :param _builtins.str loadbalancer_id: The ID of the load balancer associated with
           the requested pool.
    :param _builtins.str name: The name of the pool. Exactly one of `name`, `pool_id`
           is required to be set.
    :param _builtins.str pool_id: The ID of the pool. Exactly one of `name`, `pool_id`
           is required to be set.
    :param _builtins.str protocol: The protocol of the requested pool.
    :param _builtins.str region: The region in which to obtain the V2 Load Balancer
           client. If omitted, the `region` argument of the provider is used.
    :param Sequence[_builtins.str] tags: A set of tags applied to the loadbalancer's pool. The
           loadbalancer' pool will be returned if it has all of the specified tags.
    """
    __args__ = dict()
    __args__['lbMethod'] = lb_method
    __args__['loadbalancerId'] = loadbalancer_id
    __args__['name'] = name
    __args__['poolId'] = pool_id
    __args__['protocol'] = protocol
    __args__['region'] = region
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('openstack:loadbalancer/getPoolV2:getPoolV2', __args__, opts=opts, typ=GetPoolV2Result).value

    return AwaitableGetPoolV2Result(
        admin_state_up=pulumi.get(__ret__, 'admin_state_up'),
        alpn_protocols=pulumi.get(__ret__, 'alpn_protocols'),
        ca_tls_container_ref=pulumi.get(__ret__, 'ca_tls_container_ref'),
        crl_container_ref=pulumi.get(__ret__, 'crl_container_ref'),
        description=pulumi.get(__ret__, 'description'),
        healthmonitor_id=pulumi.get(__ret__, 'healthmonitor_id'),
        id=pulumi.get(__ret__, 'id'),
        lb_method=pulumi.get(__ret__, 'lb_method'),
        listeners=pulumi.get(__ret__, 'listeners'),
        loadbalancer_id=pulumi.get(__ret__, 'loadbalancer_id'),
        loadbalancers=pulumi.get(__ret__, 'loadbalancers'),
        members=pulumi.get(__ret__, 'members'),
        name=pulumi.get(__ret__, 'name'),
        operating_status=pulumi.get(__ret__, 'operating_status'),
        pool_id=pulumi.get(__ret__, 'pool_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        protocol=pulumi.get(__ret__, 'protocol'),
        provisioning_status=pulumi.get(__ret__, 'provisioning_status'),
        region=pulumi.get(__ret__, 'region'),
        session_persistences=pulumi.get(__ret__, 'session_persistences'),
        tags=pulumi.get(__ret__, 'tags'),
        tls_ciphers=pulumi.get(__ret__, 'tls_ciphers'),
        tls_container_ref=pulumi.get(__ret__, 'tls_container_ref'),
        tls_enabled=pulumi.get(__ret__, 'tls_enabled'),
        tls_versions=pulumi.get(__ret__, 'tls_versions'))
def get_pool_v2_output(lb_method: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       loadbalancer_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       pool_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       protocol: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPoolV2Result]:
    """
    Use this data source to get the ID of an OpenStack Load Balancer pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_openstack as openstack

    pool1 = openstack.loadbalancer.get_pool_v2(name="pool_1")
    ```


    :param _builtins.str lb_method: The load balancing algorithm to distribute traffic to the
           pool's members.
    :param _builtins.str loadbalancer_id: The ID of the load balancer associated with
           the requested pool.
    :param _builtins.str name: The name of the pool. Exactly one of `name`, `pool_id`
           is required to be set.
    :param _builtins.str pool_id: The ID of the pool. Exactly one of `name`, `pool_id`
           is required to be set.
    :param _builtins.str protocol: The protocol of the requested pool.
    :param _builtins.str region: The region in which to obtain the V2 Load Balancer
           client. If omitted, the `region` argument of the provider is used.
    :param Sequence[_builtins.str] tags: A set of tags applied to the loadbalancer's pool. The
           loadbalancer' pool will be returned if it has all of the specified tags.
    """
    __args__ = dict()
    __args__['lbMethod'] = lb_method
    __args__['loadbalancerId'] = loadbalancer_id
    __args__['name'] = name
    __args__['poolId'] = pool_id
    __args__['protocol'] = protocol
    __args__['region'] = region
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('openstack:loadbalancer/getPoolV2:getPoolV2', __args__, opts=opts, typ=GetPoolV2Result)
    return __ret__.apply(lambda __response__: GetPoolV2Result(
        admin_state_up=pulumi.get(__response__, 'admin_state_up'),
        alpn_protocols=pulumi.get(__response__, 'alpn_protocols'),
        ca_tls_container_ref=pulumi.get(__response__, 'ca_tls_container_ref'),
        crl_container_ref=pulumi.get(__response__, 'crl_container_ref'),
        description=pulumi.get(__response__, 'description'),
        healthmonitor_id=pulumi.get(__response__, 'healthmonitor_id'),
        id=pulumi.get(__response__, 'id'),
        lb_method=pulumi.get(__response__, 'lb_method'),
        listeners=pulumi.get(__response__, 'listeners'),
        loadbalancer_id=pulumi.get(__response__, 'loadbalancer_id'),
        loadbalancers=pulumi.get(__response__, 'loadbalancers'),
        members=pulumi.get(__response__, 'members'),
        name=pulumi.get(__response__, 'name'),
        operating_status=pulumi.get(__response__, 'operating_status'),
        pool_id=pulumi.get(__response__, 'pool_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        protocol=pulumi.get(__response__, 'protocol'),
        provisioning_status=pulumi.get(__response__, 'provisioning_status'),
        region=pulumi.get(__response__, 'region'),
        session_persistences=pulumi.get(__response__, 'session_persistences'),
        tags=pulumi.get(__response__, 'tags'),
        tls_ciphers=pulumi.get(__response__, 'tls_ciphers'),
        tls_container_ref=pulumi.get(__response__, 'tls_container_ref'),
        tls_enabled=pulumi.get(__response__, 'tls_enabled'),
        tls_versions=pulumi.get(__response__, 'tls_versions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TransferRequestArgs', 'TransferRequest']

@pulumi.input_type
class TransferRequestArgs:
    def __init__(__self__, *,
                 zone_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_status_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a TransferRequest resource.
        :param pulumi.Input[_builtins.str] zone_id: The ID of the zone for which to create the transfer
               request.
        :param pulumi.Input[_builtins.str] description: A description of the zone tranfer request.
        :param pulumi.Input[_builtins.bool] disable_status_check: Disable wait for zone to reach ACTIVE
               status. The check is enabled by default. If this argument is true, zone
               will be considered as created/updated if OpenStack request returned success.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 DNS client.
               If omitted, the `region` argument of the provider is used.
               Changing this creates a new DNS zone zone transfer accept.
        :param pulumi.Input[_builtins.str] target_project_id: The target Project ID to transfer to.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options. Changing this creates a
               new transfer request.
        """
        pulumi.set(__self__, "zone_id", zone_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_status_check is not None:
            pulumi.set(__self__, "disable_status_check", disable_status_check)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)

    @_builtins.property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the zone for which to create the transfer
        request.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "zone_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the zone tranfer request.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="disableStatusCheck")
    def disable_status_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable wait for zone to reach ACTIVE
        status. The check is enabled by default. If this argument is true, zone
        will be considered as created/updated if OpenStack request returned success.
        """
        return pulumi.get(self, "disable_status_check")

    @disable_status_check.setter
    def disable_status_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_status_check", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 DNS client.
        If omitted, the `region` argument of the provider is used.
        Changing this creates a new DNS zone zone transfer accept.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The target Project ID to transfer to.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_project_id", value)

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of additional options. Changing this creates a
        new transfer request.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "value_specs", value)


@pulumi.input_type
class _TransferRequestState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_status_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 zone_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransferRequest resources.
        :param pulumi.Input[_builtins.str] description: A description of the zone tranfer request.
        :param pulumi.Input[_builtins.bool] disable_status_check: Disable wait for zone to reach ACTIVE
               status. The check is enabled by default. If this argument is true, zone
               will be considered as created/updated if OpenStack request returned success.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 DNS client.
               If omitted, the `region` argument of the provider is used.
               Changing this creates a new DNS zone zone transfer accept.
        :param pulumi.Input[_builtins.str] target_project_id: The target Project ID to transfer to.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options. Changing this creates a
               new transfer request.
        :param pulumi.Input[_builtins.str] zone_id: The ID of the zone for which to create the transfer
               request.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if disable_status_check is not None:
            pulumi.set(__self__, "disable_status_check", disable_status_check)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)
        if value_specs is not None:
            pulumi.set(__self__, "value_specs", value_specs)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A description of the zone tranfer request.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="disableStatusCheck")
    def disable_status_check(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Disable wait for zone to reach ACTIVE
        status. The check is enabled by default. If this argument is true, zone
        will be considered as created/updated if OpenStack request returned success.
        """
        return pulumi.get(self, "disable_status_check")

    @disable_status_check.setter
    def disable_status_check(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_status_check", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 DNS client.
        If omitted, the `region` argument of the provider is used.
        Changing this creates a new DNS zone zone transfer accept.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The target Project ID to transfer to.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_project_id", value)

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Map of additional options. Changing this creates a
        new transfer request.
        """
        return pulumi.get(self, "value_specs")

    @value_specs.setter
    def value_specs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "value_specs", value)

    @_builtins.property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the zone for which to create the transfer
        request.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("openstack:dns/transferRequest:TransferRequest")
class TransferRequest(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_status_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 zone_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a DNS zone transfer request in the OpenStack DNS Service.

        ## Example Usage

        ### Automatically detect the correct network

        ```python
        import pulumi
        import pulumi_openstack as openstack

        example_zone = openstack.dns.Zone("example_zone",
            name="example.com.",
            email="jdoe@example.com",
            description="An example zone",
            ttl=3000,
            type="PRIMARY")
        request1 = openstack.dns.TransferRequest("request_1",
            zone_id=example_zone.id,
            description="a transfer request")
        ```

        ## Import

        This resource can be imported by specifying the transferRequest ID:

        ```sh
        $ pulumi import openstack:dns/transferRequest:TransferRequest request_1 request_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description of the zone tranfer request.
        :param pulumi.Input[_builtins.bool] disable_status_check: Disable wait for zone to reach ACTIVE
               status. The check is enabled by default. If this argument is true, zone
               will be considered as created/updated if OpenStack request returned success.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 DNS client.
               If omitted, the `region` argument of the provider is used.
               Changing this creates a new DNS zone zone transfer accept.
        :param pulumi.Input[_builtins.str] target_project_id: The target Project ID to transfer to.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options. Changing this creates a
               new transfer request.
        :param pulumi.Input[_builtins.str] zone_id: The ID of the zone for which to create the transfer
               request.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransferRequestArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a DNS zone transfer request in the OpenStack DNS Service.

        ## Example Usage

        ### Automatically detect the correct network

        ```python
        import pulumi
        import pulumi_openstack as openstack

        example_zone = openstack.dns.Zone("example_zone",
            name="example.com.",
            email="jdoe@example.com",
            description="An example zone",
            ttl=3000,
            type="PRIMARY")
        request1 = openstack.dns.TransferRequest("request_1",
            zone_id=example_zone.id,
            description="a transfer request")
        ```

        ## Import

        This resource can be imported by specifying the transferRequest ID:

        ```sh
        $ pulumi import openstack:dns/transferRequest:TransferRequest request_1 request_id
        ```

        :param str resource_name: The name of the resource.
        :param TransferRequestArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransferRequestArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_status_check: Optional[pulumi.Input[_builtins.bool]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 zone_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransferRequestArgs.__new__(TransferRequestArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["disable_status_check"] = disable_status_check
            __props__.__dict__["key"] = key
            __props__.__dict__["region"] = region
            __props__.__dict__["target_project_id"] = target_project_id
            __props__.__dict__["value_specs"] = value_specs
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
        super(TransferRequest, __self__).__init__(
            'openstack:dns/transferRequest:TransferRequest',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            disable_status_check: Optional[pulumi.Input[_builtins.bool]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            target_project_id: Optional[pulumi.Input[_builtins.str]] = None,
            value_specs: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            zone_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'TransferRequest':
        """
        Get an existing TransferRequest resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A description of the zone tranfer request.
        :param pulumi.Input[_builtins.bool] disable_status_check: Disable wait for zone to reach ACTIVE
               status. The check is enabled by default. If this argument is true, zone
               will be considered as created/updated if OpenStack request returned success.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 DNS client.
               If omitted, the `region` argument of the provider is used.
               Changing this creates a new DNS zone zone transfer accept.
        :param pulumi.Input[_builtins.str] target_project_id: The target Project ID to transfer to.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] value_specs: Map of additional options. Changing this creates a
               new transfer request.
        :param pulumi.Input[_builtins.str] zone_id: The ID of the zone for which to create the transfer
               request.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransferRequestState.__new__(_TransferRequestState)

        __props__.__dict__["description"] = description
        __props__.__dict__["disable_status_check"] = disable_status_check
        __props__.__dict__["key"] = key
        __props__.__dict__["region"] = region
        __props__.__dict__["target_project_id"] = target_project_id
        __props__.__dict__["value_specs"] = value_specs
        __props__.__dict__["zone_id"] = zone_id
        return TransferRequest(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A description of the zone tranfer request.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="disableStatusCheck")
    def disable_status_check(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Disable wait for zone to reach ACTIVE
        status. The check is enabled by default. If this argument is true, zone
        will be considered as created/updated if OpenStack request returned success.
        """
        return pulumi.get(self, "disable_status_check")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 DNS client.
        If omitted, the `region` argument of the provider is used.
        Changing this creates a new DNS zone zone transfer accept.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The target Project ID to transfer to.
        """
        return pulumi.get(self, "target_project_id")

    @_builtins.property
    @pulumi.getter(name="valueSpecs")
    def value_specs(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Map of additional options. Changing this creates a
        new transfer request.
        """
        return pulumi.get(self, "value_specs")

    @_builtins.property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the zone for which to create the transfer
        request.
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PortForwardingV2Args', 'PortForwardingV2']

@pulumi.input_type
class PortForwardingV2Args:
    def __init__(__self__, *,
                 external_port: pulumi.Input[_builtins.int],
                 floatingip_id: pulumi.Input[_builtins.str],
                 internal_ip_address: pulumi.Input[_builtins.str],
                 internal_port: pulumi.Input[_builtins.int],
                 internal_port_id: pulumi.Input[_builtins.str],
                 protocol: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PortForwardingV2 resource.
        :param pulumi.Input[_builtins.int] external_port: The TCP/UDP/other protocol port number of the port forwarding. Changing this
               updates the `external_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] floatingip_id: The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        :param pulumi.Input[_builtins.str] internal_ip_address: The fixed IPv4 address of the Neutron port associated with the port forwarding.
               Changing this updates the `internal_ip_address` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] internal_port: The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
               port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] internal_port_id: The ID of the Neutron port associated with the port forwarding. Changing
               this updates the `internal_port_id` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] protocol: The IP protocol used in the port forwarding. Changing this updates the `protocol`
               of an existing port forwarding.
        :param pulumi.Input[_builtins.str] description: A text describing the port forwarding. Changing this
               updates the `description` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a port forwarding. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               port forwarding.
        """
        pulumi.set(__self__, "external_port", external_port)
        pulumi.set(__self__, "floatingip_id", floatingip_id)
        pulumi.set(__self__, "internal_ip_address", internal_ip_address)
        pulumi.set(__self__, "internal_port", internal_port)
        pulumi.set(__self__, "internal_port_id", internal_port_id)
        pulumi.set(__self__, "protocol", protocol)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Input[_builtins.int]:
        """
        The TCP/UDP/other protocol port number of the port forwarding. Changing this
        updates the `external_port` of an existing port forwarding.
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "external_port", value)

    @_builtins.property
    @pulumi.getter(name="floatingipId")
    def floatingip_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        """
        return pulumi.get(self, "floatingip_id")

    @floatingip_id.setter
    def floatingip_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "floatingip_id", value)

    @_builtins.property
    @pulumi.getter(name="internalIpAddress")
    def internal_ip_address(self) -> pulumi.Input[_builtins.str]:
        """
        The fixed IPv4 address of the Neutron port associated with the port forwarding.
        Changing this updates the `internal_ip_address` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_ip_address")

    @internal_ip_address.setter
    def internal_ip_address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "internal_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Input[_builtins.int]:
        """
        The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
        port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "internal_port", value)

    @_builtins.property
    @pulumi.getter(name="internalPortId")
    def internal_port_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Neutron port associated with the port forwarding. Changing
        this updates the `internal_port_id` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port_id")

    @internal_port_id.setter
    def internal_port_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "internal_port_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[_builtins.str]:
        """
        The IP protocol used in the port forwarding. Changing this updates the `protocol`
        of an existing port forwarding.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A text describing the port forwarding. Changing this
        updates the `description` of an existing port forwarding.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a port forwarding. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        port forwarding.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _PortForwardingV2State:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_port: Optional[pulumi.Input[_builtins.int]] = None,
                 floatingip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PortForwardingV2 resources.
        :param pulumi.Input[_builtins.str] description: A text describing the port forwarding. Changing this
               updates the `description` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] external_port: The TCP/UDP/other protocol port number of the port forwarding. Changing this
               updates the `external_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] floatingip_id: The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        :param pulumi.Input[_builtins.str] internal_ip_address: The fixed IPv4 address of the Neutron port associated with the port forwarding.
               Changing this updates the `internal_ip_address` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] internal_port: The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
               port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] internal_port_id: The ID of the Neutron port associated with the port forwarding. Changing
               this updates the `internal_port_id` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] protocol: The IP protocol used in the port forwarding. Changing this updates the `protocol`
               of an existing port forwarding.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a port forwarding. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               port forwarding.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if external_port is not None:
            pulumi.set(__self__, "external_port", external_port)
        if floatingip_id is not None:
            pulumi.set(__self__, "floatingip_id", floatingip_id)
        if internal_ip_address is not None:
            pulumi.set(__self__, "internal_ip_address", internal_ip_address)
        if internal_port is not None:
            pulumi.set(__self__, "internal_port", internal_port)
        if internal_port_id is not None:
            pulumi.set(__self__, "internal_port_id", internal_port_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A text describing the port forwarding. Changing this
        updates the `description` of an existing port forwarding.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The TCP/UDP/other protocol port number of the port forwarding. Changing this
        updates the `external_port` of an existing port forwarding.
        """
        return pulumi.get(self, "external_port")

    @external_port.setter
    def external_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "external_port", value)

    @_builtins.property
    @pulumi.getter(name="floatingipId")
    def floatingip_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        """
        return pulumi.get(self, "floatingip_id")

    @floatingip_id.setter
    def floatingip_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "floatingip_id", value)

    @_builtins.property
    @pulumi.getter(name="internalIpAddress")
    def internal_ip_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The fixed IPv4 address of the Neutron port associated with the port forwarding.
        Changing this updates the `internal_ip_address` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_ip_address")

    @internal_ip_address.setter
    def internal_ip_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "internal_ip_address", value)

    @_builtins.property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
        port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port")

    @internal_port.setter
    def internal_port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "internal_port", value)

    @_builtins.property
    @pulumi.getter(name="internalPortId")
    def internal_port_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Neutron port associated with the port forwarding. Changing
        this updates the `internal_port_id` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port_id")

    @internal_port_id.setter
    def internal_port_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "internal_port_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP protocol used in the port forwarding. Changing this updates the `protocol`
        of an existing port forwarding.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a port forwarding. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        port forwarding.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.type_token("openstack:networking/portForwardingV2:PortForwardingV2")
class PortForwardingV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_port: Optional[pulumi.Input[_builtins.int]] = None,
                 floatingip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a V2 portforwarding resource within OpenStack.

        ## Example Usage

        ### Simple portforwarding

        ```python
        import pulumi
        import pulumi_openstack as openstack

        pf1 = openstack.networking.PortForwardingV2("pf_1",
            floatingip_id="7a52eb59-7d47-415d-a884-046666a6fbae",
            external_port=7233,
            internal_port=25,
            internal_port_id="b930d7f6-ceb7-40a0-8b81-a425dd994ccf",
            protocol="tcp")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A text describing the port forwarding. Changing this
               updates the `description` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] external_port: The TCP/UDP/other protocol port number of the port forwarding. Changing this
               updates the `external_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] floatingip_id: The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        :param pulumi.Input[_builtins.str] internal_ip_address: The fixed IPv4 address of the Neutron port associated with the port forwarding.
               Changing this updates the `internal_ip_address` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] internal_port: The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
               port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] internal_port_id: The ID of the Neutron port associated with the port forwarding. Changing
               this updates the `internal_port_id` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] protocol: The IP protocol used in the port forwarding. Changing this updates the `protocol`
               of an existing port forwarding.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a port forwarding. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               port forwarding.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PortForwardingV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a V2 portforwarding resource within OpenStack.

        ## Example Usage

        ### Simple portforwarding

        ```python
        import pulumi
        import pulumi_openstack as openstack

        pf1 = openstack.networking.PortForwardingV2("pf_1",
            floatingip_id="7a52eb59-7d47-415d-a884-046666a6fbae",
            external_port=7233,
            internal_port=25,
            internal_port_id="b930d7f6-ceb7-40a0-8b81-a425dd994ccf",
            protocol="tcp")
        ```

        :param str resource_name: The name of the resource.
        :param PortForwardingV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PortForwardingV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 external_port: Optional[pulumi.Input[_builtins.int]] = None,
                 floatingip_id: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
                 internal_port: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_port_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PortForwardingV2Args.__new__(PortForwardingV2Args)

            __props__.__dict__["description"] = description
            if external_port is None and not opts.urn:
                raise TypeError("Missing required property 'external_port'")
            __props__.__dict__["external_port"] = external_port
            if floatingip_id is None and not opts.urn:
                raise TypeError("Missing required property 'floatingip_id'")
            __props__.__dict__["floatingip_id"] = floatingip_id
            if internal_ip_address is None and not opts.urn:
                raise TypeError("Missing required property 'internal_ip_address'")
            __props__.__dict__["internal_ip_address"] = internal_ip_address
            if internal_port is None and not opts.urn:
                raise TypeError("Missing required property 'internal_port'")
            __props__.__dict__["internal_port"] = internal_port
            if internal_port_id is None and not opts.urn:
                raise TypeError("Missing required property 'internal_port_id'")
            __props__.__dict__["internal_port_id"] = internal_port_id
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["region"] = region
        super(PortForwardingV2, __self__).__init__(
            'openstack:networking/portForwardingV2:PortForwardingV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            external_port: Optional[pulumi.Input[_builtins.int]] = None,
            floatingip_id: Optional[pulumi.Input[_builtins.str]] = None,
            internal_ip_address: Optional[pulumi.Input[_builtins.str]] = None,
            internal_port: Optional[pulumi.Input[_builtins.int]] = None,
            internal_port_id: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'PortForwardingV2':
        """
        Get an existing PortForwardingV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: A text describing the port forwarding. Changing this
               updates the `description` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] external_port: The TCP/UDP/other protocol port number of the port forwarding. Changing this
               updates the `external_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] floatingip_id: The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        :param pulumi.Input[_builtins.str] internal_ip_address: The fixed IPv4 address of the Neutron port associated with the port forwarding.
               Changing this updates the `internal_ip_address` of an existing port forwarding.
        :param pulumi.Input[_builtins.int] internal_port: The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
               port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] internal_port_id: The ID of the Neutron port associated with the port forwarding. Changing
               this updates the `internal_port_id` of an existing port forwarding.
        :param pulumi.Input[_builtins.str] protocol: The IP protocol used in the port forwarding. Changing this updates the `protocol`
               of an existing port forwarding.
        :param pulumi.Input[_builtins.str] region: The region in which to obtain the V2 networking client.
               A networking client is needed to create a port forwarding. If omitted, the
               `region` argument of the provider is used. Changing this creates a new
               port forwarding.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PortForwardingV2State.__new__(_PortForwardingV2State)

        __props__.__dict__["description"] = description
        __props__.__dict__["external_port"] = external_port
        __props__.__dict__["floatingip_id"] = floatingip_id
        __props__.__dict__["internal_ip_address"] = internal_ip_address
        __props__.__dict__["internal_port"] = internal_port
        __props__.__dict__["internal_port_id"] = internal_port_id
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["region"] = region
        return PortForwardingV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A text describing the port forwarding. Changing this
        updates the `description` of an existing port forwarding.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="externalPort")
    def external_port(self) -> pulumi.Output[_builtins.int]:
        """
        The TCP/UDP/other protocol port number of the port forwarding. Changing this
        updates the `external_port` of an existing port forwarding.
        """
        return pulumi.get(self, "external_port")

    @_builtins.property
    @pulumi.getter(name="floatingipId")
    def floatingip_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Neutron floating IP address. Changing this creates a new port forwarding.
        """
        return pulumi.get(self, "floatingip_id")

    @_builtins.property
    @pulumi.getter(name="internalIpAddress")
    def internal_ip_address(self) -> pulumi.Output[_builtins.str]:
        """
        The fixed IPv4 address of the Neutron port associated with the port forwarding.
        Changing this updates the `internal_ip_address` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_ip_address")

    @_builtins.property
    @pulumi.getter(name="internalPort")
    def internal_port(self) -> pulumi.Output[_builtins.int]:
        """
        The TCP/UDP/other protocol port number of the Neutron port fixed IP address associated to the
        port forwarding. Changing this updates the `internal_port` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port")

    @_builtins.property
    @pulumi.getter(name="internalPortId")
    def internal_port_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Neutron port associated with the port forwarding. Changing
        this updates the `internal_port_id` of an existing port forwarding.
        """
        return pulumi.get(self, "internal_port_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        The IP protocol used in the port forwarding. Changing this updates the `protocol`
        of an existing port forwarding.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which to obtain the V2 networking client.
        A networking client is needed to create a port forwarding. If omitted, the
        `region` argument of the provider is used. Changing this creates a new
        port forwarding.
        """
        return pulumi.get(self, "region")

